@@ -14,4 +14,5 @@ amiga halo finder frontend
 #-----------------------------------------------------------------------------
 
 from ytree.frontends.ahf.arbor import \
-    AHFArbor
+    AHFArbor, \
+    AHFNewArbor
